package modele;

import java.util.ArrayList ;

import classes_metiers.Morpion;


/**
 * Modèle du jeu de Morpion
 * @author Dominique Bouthinon, révisé par B. KHAFIF
 * 
 */
public class ModeleMorpion extends Morpion implements InterfaceModeleMorpion
{

	private ArrayList<Observateur> observateurs ;


	public ModeleMorpion()
	{
		/**
		 * Instanciation de l'une liste d'Observateur vide
		 */
		this.observateurs = new ArrayList<Observateur>() ;
	}

	
	

	/**
	 * Joue le Coup proposé par le dernier joueur
	 * @param ligne : (int) ligne du dernier du coup joué
	 * @param colonne : (int) colonne du dernier coup joué 
	 * @throws Exception: coup non valide
	 */
	public void joueCoup(int ligne, int colonne) throws Exception
	{
		super.joueCoup(ligne, colonne);

		this.notifierObservateurs() ;
	}
	

	/**
	 * En tant qu'Observable
	 */

	/**
	 * Permet à un sujet de s'enregistrer auprès du modèle
	 */
	public void enregistrerObservateur(Observateur o)
	{
		this.observateurs.add(o) ;
	}

	/**
	 * Permet à un sujet de se désincrire auprès du modèle
	 */
	public void supprimerObservateur(Observateur o) 
	{
		this.observateurs.remove(o) ;
	}


	/**
	 * Notification d'un changement du modèle à tous ses sujets
	 */
	public void notifierObservateurs() 
	{
		for (int i = 0 ; i < this.observateurs.size() ; i++)
		{
			this.observateurs.get(i).actualiser() ;
		}
	}

}
// fin class ModelMorpion
